customeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# customeditor

class `camelot.view.controls.editors.customeditor.` `AbstractCustomEditor`

  Helper class to be used to build custom editors. This class provides functionality to store and retrieve ValueLoading as an editor’s value.

  Guidelines for implementing CustomEditors :

  - When an editor consists of multiple widgets, one widget must be the focusProxy of the editor, to have that widget immediately activated when the user single clicks in the table view.
  - When an editor has widgets that should not get selected when the user tabs through the editor, setFocusPolicy(Qt.ClickFocus) should be called on those widgets.

class `camelot.view.controls.editors.customeditor.` `CustomEditor`(parent)

  Base class for implementing custom editor widgets. This class provides dual state functionality. Each editor should have the posibility to have ValueLoading as its value, specifying that no value has been set yet.

`camelot.view.controls.editors.customeditor.` `draw_tooltip_visualization`(widget)

  Draws a small visual indication in the top-left corner of a widget. :param widget: a QWidget

`camelot.view.controls.editors.customeditor.` `set_background_color_palette`(widget, background_color)

  Set the palette of a widget to have a cerain background color. :param widget: a QWidget :param background_color: a QColor

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus